#!/bin/bash

MIRROR_SERVER="http://mirror.vitalinux.educa.aragon.es"

function create_source_list() {
    local _SRV=$1
    local proxy_file="/etc/apt/apt.conf.d/01cache_proxy"
    . /etc/default/vx-dga-variables/vx-dga-variables-general.conf
    #Comprobamos lo primero si el servidor caché está en la red
    if [ "$IPCACHE" != "" ] && nc -z "$IPCACHE" 3142 -w3 >/dev/null 2>&1; then
        echo "--> Servidor Cache que ofrece servicio APT-CACHER ..."
        echo "--> Se va a configurar al Servidor Cache como servidor APT-CACHER de software ..."

        echo "# Mod por migasfree-launcher: Hay conexión con el servidor APT-CACHER $IPCACHE" >/etc/apt/sources.list

        #Configuramos apt-proxy
        echo "Acquire::http { Proxy \"http://$IPCACHE:3142\"; };" >$proxy_file
        echo 'Acquire::https { Proxy "false"; };' >>$proxy_file
    else
        echo "# Mod por migasfree-launcher: NO hay conexión con algun servidor Caché" >/etc/apt/sources.list
        # Borrar el posible archivo generado anteriormente del proxy-cache
        if test -f $proxy_file; then
            rm -f $proxy_file
        fi
    fi
    # Crearmos las lineas del mirror
    cat >>/etc/apt/sources.list <<EOF
# Ubuntu Base Respositorios
deb ${_SRV}/ubuntu jammy main restricted universe multiverse
deb ${_SRV}/ubuntu jammy-updates main restricted universe multiverse
deb ${_SRV}/ubuntu jammy-security main restricted multiverse universe
deb ${_SRV}/ubuntu jammy-backports main restricted multiverse universe

# Libre Office 7.6
deb ${_SRV}/libreoffice-7-6 jammy main

# Chrome. Solo para 64 bits
deb [arch=amd64] ${_SRV}/google stable main

# Openshot Developers 3.x
deb ${_SRV}/openshot-developers jammy main

# Freecad PPA
deb ${_SRV}/freecad jammy main

# Remmina PPA
deb ${_SRV}/remmina-next jammy main

# Gimp UbuntuHandbook PPA
deb ${_SRV}/ubuntuhandbookgimp jammy main

# Firefox Mozilla Team
deb ${_SRV}/mozillafirefox jammy main

# Chromium PPA 
deb ${_SRV}/chromium jammy main

# Wine-HQ 
deb ${_SRV}/winehq jammy main
EOF
}

# Función para revisar e instalar claves. Primer parámetro es la clave y segundo el servidor de claves
function install_apt_key() {
    # Ahora el ID de la clave son los 4 grupos de 4 de la huella larga....
    # Para descargarla, solo deberemos quitar los espacios de la huella para buscarla en el server
    if ! (apt-key list | grep "${1}") >/dev/null 2>&1; then
        echo "Clave ${3} no encontrada...Instalando"
        KEY=${1// /}
        apt-key adv --keyserver "${2}" --recv-keys "${KEY}"
        return $?
    fi
}

function searchkey_local_install() {
    # Por rapidez, podemos darle instalar la clave si tenemos la misma sin recurir al server de keys
    ## Ventajas: rapidez
    ## Desventaja: si cambia la clave, hay que actualizar la función
    # La podemos extraer de un equipo que ya la tenga con: apt-key export "089EBE08314DF160"
    if ! (apt-key list | grep "${1}") >/dev/null 2>&1; then
        KEY=${1// /}
        ${KEY} | apt-key add - >/dev/null 2>&1
    fi
}
function 83FBA1751378B444() {
    # Libreoffice
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ETRuApgEEAKFfVq0Yu0rBdnipWkI9WOW6X1xrzrpSWE+bTakWbNASr3f5RENb
k0JEOGayoyIynRj2GHxAtD116BApkF3IdtikrEBDZKirgUOlq9EpSyP0EwbP/n40
p9VcWH4KHyR9pILKuiU1t0u70VSakvB1+KkOqs2oei0TFnDYbYH5pmWHABEBAAG0
J0xhdW5jaHBhZCBQUEEgZm9yIExpYnJlT2ZmaWNlIFBhY2thZ2luZ4i4BBMBAgAi
BQJNG4CmAhsDBgsJCAcDAgYVCAIJCgsEFgIDAQIeAQIXgAAKCRCD+6F1E3i0ROAG
A/9otE7tGoigHssjm9SG9vwVTGYF+0QQX2uwiQJmChXdqtt1y+YRv5bq61KGfu46
DNc0QlJIgaOW+6hp/L5QwTrNIp7psjDPUjTQ0qo0ZSRb67WJjNKeR78PGtxYRNH+
S67HBEFatbF7EPVuoqTS38myroYRQtTHuXD2zwqM8WSPNokCHAQQAQIABgUCTTBX
PwAKCRC5byMArRHL7tm0EADDPtdJwqu4RQGdbI1KONhkoh5y5H4aEc0jQDe1VjTh
XrZYnWrkBZvb3dhwtiA4CT+hWiZQnilue+SfACCdjdNQY6neP1Y4czLq6ApErVZa
9rL7tvMxrrhShLLxTDBrLrXDGsLE9AGKwe4GicuB0rh1JWiWawhygu1CZhm+7paX
p7njh+IPbRTf3q8hHLWVGeFyaro7fQiUmfi/q5ljsqMfTBDdPmL4+vOpBTvFNsUv
U2vHii2C+/p/la3xZM6r3j7O00FRDMPr64dt3hDkJgOKrX2Cxat6w6Nuw+yVw2k6
9WgP3zZZEieIKytBoEJ9nLycdJhdeLToJ/7R2iZJBhdUjpMbzyQ0c9YiaUKs8YP6
wZftZHbG7JsiHXpUkMqlnz9PDBWm1K3bXbaClcT9h6ISzeYqKspLjJ4PPMejELiI
7X/hNQ2+LlCe8epjENyNCC0/pdzMudOpwkgc3D8TkLo1+EH64gPRPNzR4EdedGWn
UpWiNwtkz8eSh5EYC2Ucv1NwUfaj77GDnTprX0bOGWbYp+OiT6OxIKpospfcNhqZ
1YxtNVM8d8cFCQKU4LiDMQZL0uQm7dsFFmUwR5rTr2ZCY+JNUfAoE7IdGWo9St50
DIVyEhPNZuwiYy5nX54MIWmhCpzv8Yr2SXtxYcfMZ6qxaGxYyyD1d3T0WrqjxNN+
EokBnAQRAQoABgUCTqmikwAKCRCg8hPxRutYHyecDACQ9orO4sA3BMPGUN6VKcSP
nIu5UiaYHoucE2vrq5BBuLSgKM/T77YtFWXWEMcPJQH89b4E/O92Dz+qn1Rlb4jI
5yK0yvxPE8i8A0JvEa7IdQSfYn/NZFuG7wDNDopNj9QjZv2QHvu4ZanDrcP+FWUw
BujVMJTTP60UPwWSL6J0N0aKGWJ8OBNo0XrmYrAacvEIt6ytu79liUeO1afw97yi
fT9QafYlW2sziJEfyqHKnHRaC7fAhPM8p+x0G1EeKO7iQsTqZHIGmEDoSIIvNhEa
elP8xZ8mRLdeA5B+33mbb2KSjEzXu3GLXQ7L9TxtNu1n5M40Tcu6algWTqwnnqEh
afN4KKt5DNt4v+F7igEQEmKj7MHsHZV5f/lXvWci84T/nqE9KcBF7QsGjzEHtpz1
dTZdZk6pJvTOpY52QURWhIlsyeYbG7GzSsRIZOoS4CD+sMEgmlBVQ9AwQC5tvWWa
otnR4sNTPVp/o6NiPtrQi+LjAWS39c4pfOgM38J3Fik=
=by/p
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 52165BD6B9BA26FA() {
    # Openshot
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----
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=NHN7
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 005EAE8119BB5BCA() {
    # Freecad
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ETYF+BAEEAK1n4CPNzdG/rTNvteUkHOiSikl07GJl7jh8RjL4T2BA3g2J0M0g
x20gOfc2Srbmg676cdf2kIzhfVPbjvWJnDYsFS1BOa0ZsKb0xN6lZzMU2lhmPMgF
jJJk94BqeLlxr9wSqmOkR8X3yDtNWbZ+5xO1wDUP4GDZcCwesVsWfdXZABEBAAG0
JUxhdW5jaHBhZCBQUEEgZm9yIEZyZWVDQUQgbWFpbnRhaW5lcnOIuAQTAQIAIgUC
TYF+BAIbAwYLCQgHAwIGFQgCCQoLBBYCAwECHgECF4AACgkQAF6ugRm7W8oktwP+
Nzk9OEg3kl8fNd9JeTWrw2UnisfPOIV7HTATpLqnXZQOQ+Q7QjsRL6yRMj+U6OWa
9pgDrljJyg77DFCcHipCrR5LiXdxzzK2Z2wbStxsS2U3v7HJaXw4gmYAGyahswLa
RzbmV95JXeFAGjXM5yH6FTxbzGdH/IaXN1ASMMZQedU=
=3tnf
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 8A993C2521C5F0BA() {
    # Remmina-next
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mQINBFRuX8IBEADRAN5+JtzhrVIM2pe48sinBwwU/NlCbfZo3RJeGXOl0AmClbUZ
2wWl9/FFdxmodJ4u+VRxPBMxSrBhj9Lp1ZvyTjgg77uDFtnFE7GyP5GYsuRi5YU+
HhxY0iHg+QjL5EYHB168Z9KfZeNcOvop8lVRL8bEfVfw7H72Vy4C9/YSCdPFvWNE
TulkLyTGBzXmH5TkqL7txP/qlp+f3IX8OVSJpF0skEZNMvxPHuTI5qwOyBT0pPPO
649vdVezfr6EbegbMHxR5zljfUHx70ta4Y2BHG5IrU/x103R/uoJqX1X7B/FNPoh
lkKpsgD5h8ccLWNvSxfIHdN9hX+qYGYP8ByPzW+erwW6IoQZWR6Sr0Tk30i+8i6/
4WNUQ7OGAhNApAR1SJQO750fBF86P75zNwMt8W/LXqrmj/+Ub+UDG7JfQV1zfUA/
6CB5XVPbsv3T+Fv0xTxqJ+FdaCTF+2PFCc7UetTnXZXzl4kjPkEmTO4Kk2+g+NNb
HoZ40AHD7772+J5seiqSY6UxjTRtui55XAexRFuLQeeXs+gTkxkH1JerjU+Q/W1z
4HCYZ/kXtk5sucfs96r+7UI5Os3TBTt12cJAnyb0WgZpDtatEnhbblS26KRcOVs6
TxQy2rG2LCfxkC+T3vAzMc04McNYeAJCScv641+2nEZzw5HtgUDosqPTLwARAQAB
tCJMYXVuY2hwYWQgUFBBIGZvciBSZW1taW5hIFBQQSBUZWFtiQI4BBMBAgAiBQJU
bl/CAhsDBgsJCAcDAgYVCAIJCgsEFgIDAQIeAQIXgAAKCRCKmTwlIcXwulEvEACc
9oqQGhrFFNjMyYOdMMVH+0QYD0yeiAKdkiFi0izxEBx7bF+Vc3wdypSDlzmitYsN
/Xn1MmAxTXLC8kq+awtuh+mnoXlaJMmxK5yVjLUqVIWqT8hG5TDYmgF1ckNCK1ek
fVpMBM2tpDccXPriMvKZ5dyfVJ2GBAyaywsNu8F48BbUV8DyZThSY5H4zlGnPKcg
vbB2YFeAKgW2khPwn2zkVvgfOIW9hj+0HVfelf7hbKy/b8oIGQaj5Qg8d6ipdL8H
9fkA3RV77BsFq15NgEgHQF0O3UyxVyfRc42EozV8e7nXXKdWstq+Z/swVLB0hE0h
r5T6oRRrK4oypGpWd8ASkyIj51uakRBw3GYTgB3UL6jPTZO0BZ+YYvRmV0hyCu8E
39a2GrJJ+AQFL4ER9WB6ZKAQn2JsgxITDlz25VEbrqfY51oCBL7dMc5rgaXSXLbi
VwWZ89Lp4EhbfLXJfc+jWiIu08SOYBNC1qWSmBlMwQg4ItSiqTbfMFDOQu7VmBa2
S12g/aK1DgteeNQJ7o/Rwiu9C46RgfHVRoy//nOrsSaX71MzzQgzpj197SqMfouq
jzw+KAZ+Zh+2a/9sTiPGdDtxvctdGXBSk+g8ZNcQa1kGd/JfMcYrjVHzcOaGgFMo
XQiCklI6JFDOf9Hp1FCA5AOhAFysU5ZUw5lq56C3xQ==
=QKRB
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 4C1CBE14852541CB() {
    # Gimp UbuntuHandbook
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0EUp3DIQEEAMVlgB86QmCRyqdO1zXl8vnt9N1jfXO7JUURCDDOO8g71B4HXhue
tIZw1N2LUsvSI3CRv/z7uf/sUmn/R1J6rFsCqYAiZYKO1W917AGcBUPX0dIjiKM/
RKe3khKoHEwRGJpQHbOe3kXtJhMqqrP/pFWD1iY65TawcTLJqLLBv5UxABEBAAG0
G0xhdW5jaHBhZCBQUEEgZm9yIFBhbmRhIEppbYi4BBMBAgAiBQJSncMhAhsDBgsJ
CAcDAgYVCAIJCgsEFgIDAQIeAQIXgAAKCRBMHL4UhSVBy4E7A/9FlkunlAd/Sp47
CzNaOfPnfyEYgzDf5mW1dI434qW4zwa2XuNQQRszEancVsfu0JRwCHzd3aelEDAS
FyyXtMPG5jXs14c4auXEmFuppBU48oCfATiGdEu9yL1ayagF2PDBZZgoTVyBf4gk
66pZyO3ir/c4Zad3o+ClnzWNdzXJag==
=c9Qz
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 9BDB3D89CE49EC21() {
    # Firefox Team
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ESXMwOwEEAL7UP143coSax/7/8UdgD+WjIoIxzqhkTeoGOyw/r2DlRCBPFAOH
lsUIG3AZrHcPVzA3bRTGoEYlrQ9d0+FsUI57ozHdmlsaekEJpQ2x7wZL7c1GiRqC
A4ERrC6kNJ5ruSUHhB+8qiksLWsTyjM7OjIdkmDbH/dYKdFUEKTdljKHABEBAAG0
HkxhdW5jaHBhZCBQUEEgZm9yIE1vemlsbGEgVGVhbYi2BBMBAgAgBQJJczA7AhsD
BgsJCAcDAgQVAggDBBYCAwECHgECF4AACgkQm9s9ic5J7CGfEgP/fcx3/CSAyyWL
lnL0qjjHmfpPd8MUOKB6u4HBcBNZI2q2CnuZCBNUrMUj67IzPg2llmfXC9WxuS2c
MkGu5+AXV+Xoe6pWQd5kP1UZ44boBZH9FvOLArA4nnF2hsx4GYcxVXBvCCgUqv26
qrGpaSu9kRpuTY5r6CFdjTNWtwGsPaM=
=uNvM
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 374C7797FB006459() {
    # Chromium
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mQINBF1aDBABEADkOcYEvGYKuNtQu/F9oca6B/7ATdLQGCaTxfWPQ3PuBPKXG5aP
sLmX7HBdTX8idgkaFowAC/5X9XFqxFxIMVda/Oyr8hTKiGz+LkDPuHT9gleOxyTx
eQXhf/DCx1RbvaguB4KoAsh0WQsXcNOZFz3h6TzANjXpMvSPS7AlMXHzH0xlnzd0
EFFllb5OjmN3uYfJ+SNiXfy7eZ2pk6K50XNDAwEf7H2rNEqcHsJyRmaYnQumZCbG
enJ6t664d9sCA/8ywOB0zkpnedIwK9wfl2zZTgVkmV+Axbl3CRJ3tmT7uOG2E9np
2UnELkzhYIvt56fgH46V40Il8a15TXCRlcJPMVCqKtUkP/Ql1ncYD0WJyqYdaHOU
9LA2z/IcwVcTu4G1STjdPtvRYR4O9Uylgg6sBgbb72XfUQWJY1eAyiqnLHLtx2Ui
baOByqQ25IZGis2euW+gjJIslbPsGIigkEgzTHEwj4R66Zp/Xs6RRGyT/qAcPgMQ
PrxioQNrowYUy+wjR/0mWID4CNMaieS1+IFRMB4W3XdQDO0HwMBUmrbUUC3vkwLF
q2HAcDLQ4esIL1SMZ55zcorW0TIunSPsejxco+Re8+eR1e6Jb03Q1YR//GMsH6Cx
0FXG55ShHExbVofKDrTOZd+82kEAT3wcIcLj17NGileMWQpT3THVfmAMLwARAQAB
tB1MYXVuY2hwYWQgUFBBIGZvciBSb2IgU2F2b3VyeYkCOAQTAQIAIgUCXVoMEAIb
AwYLCQgHAwIGFQgCCQoLBBYCAwECHgECF4AACgkQN0x3l/sAZFljuw/+JYzxnZCy
n8qYik2Qm59hoPv74znOMZr24ts5XnSGsyLAORennDNA1WIatEKc3D2Ggzz/osnu
xuMSc+5ounNDIGmuuUEpoK3c+SV04oxnSBYbv9jjRId8c3eup1UAkXuW7jPivtNC
sqHyKy5JIy59AzgHFBPzU9tiUrE94JdcZLI60hl5iobGIBAi5TEohYf3pd0PH7FM
A5GFN6MPO/ih99WQcSq5I/F4CPpEx/uIirequEw9I0Ossq03aQoA0ju4zzIRxYEN
C/gl8RhzcsulKajUxon2RvMSP9targPApe83MzUegeE3AiJEdf5BWD5i00OSS8+8
tJWWI8wU7oxKrI7+hSQyjTPjxxWUfuSCAA7Ieu5/8khP2nMLhAzEuffrkvzHBwhh
RQbNcZ8jhsSuEZrBMvKv06QkVlsQGqNP20mwQkVfDq8zqnXBJ9IcvwH2Ed7cbTk6
MHab+rk4lRtjiSJn//3NDXyNgCVJlwCJAvv7H10Ozsv1qSvxqBAcnxpqQTzBIL0T
4NaZh+P6ixE7VLnu2p0F0Cm5mQskoQEFm1fb6EyYYpJqYxyg7lQae5UuMheUQ/SU
g8UKr6BV5NAAaZ7nUJaa3g/3gUgDbAoCGeCGphyn3VhoEsdTpngDbFa50vmr6Xew
/0/FyVMqgpOrHlnzxkGjcxZEj3RefWcbMy4=
=y7+f
-----END PGP PUBLIC KEY BLOCK-----
    '
}

function 76F1A20FF987672F() {
    # Winehq
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mQGNBFwOmrgBDAC9FZW3dFpew1hwDaqRfdQQ1ABcmOYu1NKZHwYjd+bGvcR2LRGe
R5dfRqG1Uc/5r6CPCMvnWxFprymkqKEADn8eFn+aCnPx03HrhA+lNEbciPfTHylt
NTTuRua7YpJIgEOjhXUbxXxnvF8fhUf5NJpJg6H6fPQARUW+5M//BlVgwn2jhzlW
U+uwgeJthhiuTXkls9Yo3EoJzmkUih+ABZgvaiBpr7GZRw9GO1aucITct0YDNTVX
KA6el78/udi5GZSCKT94yY9ArN4W6NiOFCLV7MU5d6qMjwGFhfg46NBv9nqpGinK
3NDjqCevKouhtKl2J+nr3Ju3Spzuv6Iex7tsOqt+XdZCoY+8+dy3G5zbJwBYsMiS
rTNF55PHtBH1S0QK5OoN2UR1ie/aURAyAFEMhTzvFB2B2v7C0IKIOmYMEG+DPMs9
FQs/vZ1UnAQgWk02ZiPryoHfjFO80+XYMrdWN+RSo5q9ODClloaKXjqI/aWLGirm
KXw2R8tz31go3NMAEQEAAbQnV2luZUhRIHBhY2thZ2VzIDx3aW5lLWRldmVsQHdp
bmVocS5vcmc+iQHOBBMBCgA4AhsDBQsJCAcCBhUKCQgLAgQWAgMBAh4BAheAFiEE
1D9kAUU2nFHXht3qdvGiD/mHZy8FAlwOmyUACgkQdvGiD/mHZy/zkwv7B+nKFlDY
Bzz/7j0gqIODbs5FRZRtuf/IuPP3vZdWlNfAW/VyaLtVLJCM/mmaf/O6/gJ+D+E9
BBoSmHdHzBBOQHIj5IbRedynNcHT5qXsdBeU2ZPR50sdE+jmukvw3Wa5JijoDgUu
LGLGtU48Z3JsBXQ54OlnTZXQ2SMFhRUa10JANXSJQ+QY2Wo2Pi2+MEAHcrd71A2S
0mT2DQSSBQ92c6WPfUpOSBawd8P0ipT7rVFNLJh8HVQGyEWxPl8ecDEHoVfG2rdV
D0ADbNLx9031UUwpUicO6vW/2Ec7c3VNG1cpOtyNTw/lEgvsXOh3GQs/DvFvMy/h
QzaeF3Qq6cAPlKuxieJe4lLYFBTmCAT4iB1J8oeFs4G7ScfZH4+4NBe3VGoeCD/M
Wl+qxntAroblxiFuqtPJg+NKZYWBzkptJNhnrBxcBnRinGZLw2k/GR/qPMgsR2L4
cP+OUuka+R2gp9oDVTZTyMowz+ROIxnEijF50pkj2VBFRB02rfiMp7q6iQIzBBAB
CgAdFiEE2iNXmnTUrZr50/lFzvrI6q8XUZ0FAlwOm3AACgkQzvrI6q8XUZ3KKg/+
MD8CgvLiHEX90fXQ23RZQRm2J21w3gxdIen/N8yJVIbK7NIgYhgWfGWsGQedtM7D
hMwUlDSRb4rWy9vrXBaiZoF3+nK9AcLvPChkZz28U59Jft6/l0gVrykey/ERU7EV
w1Ie1eRu0tRSXsKvMZyQH8897iHZ7uqoJgyk8U8CvSW+V80yqLB2M8Tk8ECZq34f
HqUIGs4Wo0UZh0vV4+dEQHBh1BYpmmWl+UPf7nzNwFWXu/EpjVhkExRqTnkEJ+Ai
OxbtrRn6ETKzpV4DjyifqQF639bMIem7DRRf+mkcrAXetvWkUkE76e3E9KLvETCZ
l4SBfgqSZs2vNngmpX6Qnoh883aFo5ZgVN3v6uTS+LgTwMt/XlnDQ7+Zw+ehCZ2R
CO21Y9Kbw6ZEWls/8srZdCQ2LxnyeyQeIzsLnqT/waGjQj35i4exzYeWpojVDb3r
tvvOALYGVlSYqZXIALTx2/tHXKLHyrn1C0VgHRnl+hwv7U49f7RvfQXpx47YQN/C
PWrpbG69wlKuJptr+olbyoKAWfl+UzoO8vLMo5njWQNAoAwh1H8aFUVNyhtbkRuq
l0kpy1Cmcq8uo6taK9lvYp8jak7eV8lHSSiGUKTAovNTwfZG2JboGV4/qLDUKvpa
lPp2xVpF9MzA8VlXTOzLpSyIVxZnPTpL+xR5P9WQjMS5AY0EXA6auAEMAMReKL89
0z0SL+/i/geB/agfG/k6AXiG2a9kVWeIjAqFwHKl9W/DTNvOqCDgAt51oiHGRRjt
1Xm3XZD4p+GM1uZWn9qIFL49Gt5x94TqdrsKTVCJr0Kazn2mKQc7aja0zac+WtZG
OFn7KbniuAcwtC780cyikfmmExLI1/Vjg+NiMlMtZfpK6FIW+ulPiDQPdzIhVppx
w9/KlR2Fvh4TbzDsUqkFQSSAFdQ65BWgvzLpZHdKO/ILpDkThLbipjtvbBv/pHKM
O/NFTNoYkJ3cNW/kfcynwV+4AcKwdRz2A3Mez+g5TKFYPZROIbayOo01yTMLfz2p
jcqki/t4PACtwFOhkAs+MYPPyZDUkTFcEJQCPDstkAgmJWI3K2qELtDOLQyps3WY
Mfp+mntOdc8bKjFTMcCEk1zcm14K4Oms+w6dw2UnYsX1FAYYhPm8HUYwE4kP8M+D
9HGLMjLqqF/kanlCFZs5Avx3mDSAx6zS8vtNdGh+64oDNk4x4A2j8GTUuQARAQAB
iQG8BBgBCgAmFiEE1D9kAUU2nFHXht3qdvGiD/mHZy8FAlwOmrgCGwwFCQPCZwAA
CgkQdvGiD/mHZy9FnAwAgfUkxsO53Pm2iaHhtF4+BUc8MNJj64Jvm1tghr6PBRtM
hpbvvN8SSOFwYIsS+2BMsJ2ldox4zMYhuvBcgNUlix0G0Z7h1MjftDdsLFi1DNv2
J9dJ9LdpWdiZbyg4Sy7WakIZ/VvH1Znd89Imo7kCScRdXTjIw2yCkotE5lK7A6Ns
NbVuoYEN+dbGioF4csYehnjTdojwF/19mHFxrXkdDZ/V6ZYFIFxEsxL8FEuyI4+o
LC3DFSA4+QAFdkjGFXqFPlaEJxWt5d7wk0y+tt68v+ulkJ900BvR+OOMqQURwrAi
iP3I28aRrMjZYwyqHl8i/qyIv+WRakoDKV+wWteR5DmRAPHmX2vnlPlCmY8ysR6J
2jUAfuDFVu4/qzJe6vw5tmPJMdfvy0W5oogX6sEdin5M5w2b3WrN8nXZcjbWymqP
6jCdl6eoCCkKNOIbr/MMSkd2KqAqDVM5cnnlQ7q+AXzwNpj3RGJVoBxbS0nn9JWY
QNQrWh9rAcMIGT+b1le0mQGNBFwOmrgBDAC9FZW3dFpew1hwDaqRfdQQ1ABcmOYu
1NKZHwYjd+bGvcR2LRGeR5dfRqG1Uc/5r6CPCMvnWxFprymkqKEADn8eFn+aCnPx
03HrhA+lNEbciPfTHyltNTTuRua7YpJIgEOjhXUbxXxnvF8fhUf5NJpJg6H6fPQA
RUW+5M//BlVgwn2jhzlWU+uwgeJthhiuTXkls9Yo3EoJzmkUih+ABZgvaiBpr7GZ
Rw9GO1aucITct0YDNTVXKA6el78/udi5GZSCKT94yY9ArN4W6NiOFCLV7MU5d6qM
jwGFhfg46NBv9nqpGinK3NDjqCevKouhtKl2J+nr3Ju3Spzuv6Iex7tsOqt+XdZC
oY+8+dy3G5zbJwBYsMiSrTNF55PHtBH1S0QK5OoN2UR1ie/aURAyAFEMhTzvFB2B
2v7C0IKIOmYMEG+DPMs9FQs/vZ1UnAQgWk02ZiPryoHfjFO80+XYMrdWN+RSo5q9
ODClloaKXjqI/aWLGirmKXw2R8tz31go3NMAEQEAAbQnV2luZUhRIHBhY2thZ2Vz
IDx3aW5lLWRldmVsQHdpbmVocS5vcmc+iQHOBBMBCgA4AhsDBQsJCAcCBhUKCQgL
AgQWAgMBAh4BAheAFiEE1D9kAUU2nFHXht3qdvGiD/mHZy8FAlwOmyUACgkQdvGi
D/mHZy/zkwv7B+nKFlDYBzz/7j0gqIODbs5FRZRtuf/IuPP3vZdWlNfAW/VyaLtV
LJCM/mmaf/O6/gJ+D+E9BBoSmHdHzBBOQHIj5IbRedynNcHT5qXsdBeU2ZPR50sd
E+jmukvw3Wa5JijoDgUuLGLGtU48Z3JsBXQ54OlnTZXQ2SMFhRUa10JANXSJQ+QY
2Wo2Pi2+MEAHcrd71A2S0mT2DQSSBQ92c6WPfUpOSBawd8P0ipT7rVFNLJh8HVQG
yEWxPl8ecDEHoVfG2rdVD0ADbNLx9031UUwpUicO6vW/2Ec7c3VNG1cpOtyNTw/l
EgvsXOh3GQs/DvFvMy/hQzaeF3Qq6cAPlKuxieJe4lLYFBTmCAT4iB1J8oeFs4G7
ScfZH4+4NBe3VGoeCD/MWl+qxntAroblxiFuqtPJg+NKZYWBzkptJNhnrBxcBnRi
nGZLw2k/GR/qPMgsR2L4cP+OUuka+R2gp9oDVTZTyMowz+ROIxnEijF50pkj2VBF
RB02rfiMp7q6iQIzBBABCgAdFiEE2iNXmnTUrZr50/lFzvrI6q8XUZ0FAlwOm3AA
CgkQzvrI6q8XUZ3KKg/+MD8CgvLiHEX90fXQ23RZQRm2J21w3gxdIen/N8yJVIbK
7NIgYhgWfGWsGQedtM7DhMwUlDSRb4rWy9vrXBaiZoF3+nK9AcLvPChkZz28U59J
ft6/l0gVrykey/ERU7EVw1Ie1eRu0tRSXsKvMZyQH8897iHZ7uqoJgyk8U8CvSW+
V80yqLB2M8Tk8ECZq34fHqUIGs4Wo0UZh0vV4+dEQHBh1BYpmmWl+UPf7nzNwFWX
u/EpjVhkExRqTnkEJ+AiOxbtrRn6ETKzpV4DjyifqQF639bMIem7DRRf+mkcrAXe
tvWkUkE76e3E9KLvETCZl4SBfgqSZs2vNngmpX6Qnoh883aFo5ZgVN3v6uTS+LgT
wMt/XlnDQ7+Zw+ehCZ2RCO21Y9Kbw6ZEWls/8srZdCQ2LxnyeyQeIzsLnqT/waGj
Qj35i4exzYeWpojVDb3rtvvOALYGVlSYqZXIALTx2/tHXKLHyrn1C0VgHRnl+hwv
7U49f7RvfQXpx47YQN/CPWrpbG69wlKuJptr+olbyoKAWfl+UzoO8vLMo5njWQNA
oAwh1H8aFUVNyhtbkRuql0kpy1Cmcq8uo6taK9lvYp8jak7eV8lHSSiGUKTAovNT
wfZG2JboGV4/qLDUKvpalPp2xVpF9MzA8VlXTOzLpSyIVxZnPTpL+xR5P9WQjMS5
AY0EXA6auAEMAMReKL890z0SL+/i/geB/agfG/k6AXiG2a9kVWeIjAqFwHKl9W/D
TNvOqCDgAt51oiHGRRjt1Xm3XZD4p+GM1uZWn9qIFL49Gt5x94TqdrsKTVCJr0Ka
zn2mKQc7aja0zac+WtZGOFn7KbniuAcwtC780cyikfmmExLI1/Vjg+NiMlMtZfpK
6FIW+ulPiDQPdzIhVppxw9/KlR2Fvh4TbzDsUqkFQSSAFdQ65BWgvzLpZHdKO/IL
pDkThLbipjtvbBv/pHKMO/NFTNoYkJ3cNW/kfcynwV+4AcKwdRz2A3Mez+g5TKFY
PZROIbayOo01yTMLfz2pjcqki/t4PACtwFOhkAs+MYPPyZDUkTFcEJQCPDstkAgm
JWI3K2qELtDOLQyps3WYMfp+mntOdc8bKjFTMcCEk1zcm14K4Oms+w6dw2UnYsX1
FAYYhPm8HUYwE4kP8M+D9HGLMjLqqF/kanlCFZs5Avx3mDSAx6zS8vtNdGh+64oD
Nk4x4A2j8GTUuQARAQABiQG8BBgBCgAmFiEE1D9kAUU2nFHXht3qdvGiD/mHZy8F
AlwOmrgCGwwFCQPCZwAACgkQdvGiD/mHZy9FnAwAgfUkxsO53Pm2iaHhtF4+BUc8
MNJj64Jvm1tghr6PBRtMhpbvvN8SSOFwYIsS+2BMsJ2ldox4zMYhuvBcgNUlix0G
0Z7h1MjftDdsLFi1DNv2J9dJ9LdpWdiZbyg4Sy7WakIZ/VvH1Znd89Imo7kCScRd
XTjIw2yCkotE5lK7A6NsNbVuoYEN+dbGioF4csYehnjTdojwF/19mHFxrXkdDZ/V
6ZYFIFxEsxL8FEuyI4+oLC3DFSA4+QAFdkjGFXqFPlaEJxWt5d7wk0y+tt68v+ul
kJ900BvR+OOMqQURwrAiiP3I28aRrMjZYwyqHl8i/qyIv+WRakoDKV+wWteR5DmR
APHmX2vnlPlCmY8ysR6J2jUAfuDFVu4/qzJe6vw5tmPJMdfvy0W5oogX6sEdin5M
5w2b3WrN8nXZcjbWymqP6jCdl6eoCCkKNOIbr/MMSkd2KqAqDVM5cnnlQ7q+AXzw
Npj3RGJVoBxbS0nn9JWYQNQrWh9rAcMIGT+b1le0
=VsqL
-----END PGP PUBLIC KEY BLOCK-----
    '
}

echo "=> Seguimos con la creación del sources.list ...."

## Revisión e instalación de las claves necesarias:

## Libreoffice formato dependiente de servidor claves
# install_apt_key "83FB A175 1378 B444" keyserver.ubuntu.com libreoffice

# Sin usar el server de claves 
# Libreoffice
searchkey_local_install "83FB A175 1378 B444"
# Openshot 3
searchkey_local_install "5216 5BD6 B9BA 26FA"
# Freecad
searchkey_local_install "005E AE81 19BB 5BCA"
## Remmina-next
searchkey_local_install "8A99 3C25 21C5 F0BA"
## Gimp
searchkey_local_install "4C1C BE14 8525 41CB"
## Firefox
searchkey_local_install "9BDB 3D89 CE49 EC21"
## Chromium ( ppa:savoury1/chromium)
searchkey_local_install "374C 7797 FB00 6459"
## Winehq 
searchkey_local_install "76F1 A20F F987 672F"

# Chrome. No hace uso del servidores de claves, sino de uno propio
if ! (apt-key list | grep -q "7721 F63B D38B 4796") >/dev/null 2>&1; then
    echo "Clave Google no encontrada...Instalando"
    wget -q -O - https://dl.google.com/linux/linux_signing_key.pub | apt-key add - >/dev/null
fi

# Limpiar los sources que existan antiguos
# Libreoffice
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*libreoffice.*list$' -exec mv '{}' '{}'.save \;
# Chrome
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*chrome.*list$' -exec mv '{}' '{}'.save \;
# openshot
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*openshot.*list$' -exec mv '{}' '{}'.save \;
# freecad
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*freecad.*list$' -exec mv '{}' '{}'.save \;
# Remmina
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*remmina.*list$' -exec mv '{}' '{}'.save \;
# Gimp
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*gimp.*list$' -exec mv '{}' '{}'.save \;
# Geogebra
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*geogebra.*list$' -exec mv '{}' '{}'.save \;

# Creamos el sources.list
create_source_list $MIRROR_SERVER
